@@ -22,7 +22,7 @@ namespace pl::core::ast {
         this->m_entries.emplace_back(std::move(entry));
     }
 
-    [[nodiscard]] std::vector<std::shared_ptr<ptrn::Pattern>> ASTNodeBitfield::createPatterns(Evaluator *evaluator) const {
+    void ASTNodeBitfield::createPatterns(Evaluator *evaluator, std::vector<std::shared_ptr<ptrn::Pattern>> &resultPatterns) const {
         [[maybe_unused]] auto context = evaluator->updateRuntime(this);
 
         auto position = evaluator->getBitwiseReadOffset();
@@ -56,7 +56,7 @@ namespace pl::core::ast {
             BitfieldOrder order = [&]() {
                 if (auto *literalNode = dynamic_cast<ASTNodeLiteral *>(directionNode.get()); literalNode != nullptr) {
                     auto value = literalNode->getValue().toUnsigned();
-                    switch (value) {
+                    switch (u32(value)) {
                         case u32(BitfieldOrder::MostToLeastSignificant):
                             return BitfieldOrder::MostToLeastSignificant;
                         case u32(BitfieldOrder::LeastToMostSignificant):
@@ -81,7 +81,7 @@ namespace pl::core::ast {
                                     || (order == BitfieldOrder::LeastToMostSignificant && bitfieldPattern->getEndian() == std::endian::big);
             if (prevReversed != shouldBeReversed) {
                 reversedChanged = true;
-                wolv::util::unused(evaluator->getBitwiseReadOffsetAndIncrement(size));
+                wolv::util::unused(evaluator->getBitwiseReadOffsetAndIncrement(i128(size)));
                 evaluator->setReadOrderReversed(shouldBeReversed);
             }
 
@@ -90,13 +90,24 @@ namespace pl::core::ast {
 
         std::vector<std::shared_ptr<ptrn::Pattern>> fields;
         std::vector<std::shared_ptr<ptrn::Pattern>> potentialPatterns;
+        auto initialPosition = evaluator->getBitwiseReadOffset();
 
         evaluator->pushScope(bitfieldPattern, potentialPatterns);
-        ON_SCOPE_EXIT {
-                          evaluator->popScope();
-                      };
 
-        auto initialPosition = evaluator->getBitwiseReadOffset();
+        ON_SCOPE_EXIT {
+            bitfieldPattern->setReversed(evaluator->isReadOrderReversed());
+            if (reversedChanged)
+                evaluator->setBitwiseReadOffset(initialPosition);
+            bitfieldPattern->setFields(fields);
+
+            applyTypeAttributes(evaluator, this, bitfieldPattern);
+
+            resultPatterns = hlp::moveToVector<std::shared_ptr<ptrn::Pattern>>(std::move(bitfieldPattern));
+
+            evaluator->setReadOrderReversed(prevReversed);
+            evaluator->popScope();
+        };
+
         auto setSize = [&](ASTNode *node) {
             auto endPosition = evaluator->getBitwiseReadOffset();
             auto startOffset = (initialPosition.byteOffset * 8) + initialPosition.bitOffset;
@@ -105,47 +116,36 @@ namespace pl::core::ast {
             if (fixedSize > 0) {
                 if (totalBitSize > fixedSize)
                     err::E0005.throwError("Bitfield's fields exceeded the attribute-allotted size.", {}, node->getLocation());
-                totalBitSize = fixedSize;
+                totalBitSize = u64(fixedSize);
             }
             bitfieldPattern->setBitSize(totalBitSize);
         };
 
         for (auto &entry : this->m_entries) {
-            auto patterns = entry->createPatterns(evaluator);
+            std::vector<std::shared_ptr<ptrn::Pattern>> patterns;
+            entry->createPatterns(evaluator, patterns);
             setSize(entry.get());
+
+            if (evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Continue) {
+                break;
+            }
+
             std::move(patterns.begin(), patterns.end(), std::back_inserter(potentialPatterns));
-
-            if (evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Return)
-                break;
-
-            if (evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Break) {
-                break;
-            } else if (evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Continue) {
-                potentialPatterns.clear();
+            
+            if (evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Return || evaluator->getCurrentControlFlowStatement() == ControlFlowStatement::Break) {
                 break;
             }
         }
 
         for (auto &pattern : potentialPatterns) {
             if (auto bitfieldMember = dynamic_cast<ptrn::PatternBitfieldMember*>(pattern.get()); bitfieldMember != nullptr) {
-                bitfieldMember->setParentBitfield(bitfieldPattern.get());
+                bitfieldMember->setParent(bitfieldPattern.get());
                 if (!bitfieldMember->isPadding())
                     fields.push_back(pattern);
             } else {
                 fields.push_back(pattern);
             }
         }
-
-        bitfieldPattern->setReversed(evaluator->isReadOrderReversed());
-        if (reversedChanged)
-            evaluator->setBitwiseReadOffset(initialPosition);
-        bitfieldPattern->setFields(fields);
-
-        applyTypeAttributes(evaluator, this, bitfieldPattern);
-
-        evaluator->setReadOrderReversed(prevReversed);
-
-        return hlp::moveToVector<std::shared_ptr<ptrn::Pattern>>(std::move(bitfieldPattern));
     }
 
 }
\ No newline at end of file
